@@ -1,5 +1,6 @@
 /* 
- * Copyright (C) 1999-2002 Inter7 Internet Technologies, Inc. 
+ * $Id: qmailadmin.h,v 1.1.1.1.2.6 2006/02/05 17:07:27 tomcollins Exp $
+ * Copyright (C) 1999-2004 Inter7 Internet Technologies, Inc. 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +17,18 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <time.h>
+
+/* Some platforms use '.maildir' instead of 'Maildir' as the mail directory
+ * name.  Furture versions of Vpopmail might define it.  Until then, change
+ * it below.
+ */
+#ifndef MAILDIR
+#define MAILDIR "Maildir"
+#endif
+
+/* max # of forwards a user can set on the Modify User screen */
+#define MAX_FORWARD_PER_USER 5
 
 #define QMAILADMIN_TEMPLATEDIR "QMAILADMIN_TEMPLATEDIR"
 
@@ -23,27 +36,31 @@
 
 #define MAX_FILE_NAME 100
 
+#ifdef MAX_BUFF
+#undef MAX_BUFF
+#endif
 #define MAX_BUFF 500
 #define MAX_BIG_BUFF 5000
 
-#define QMAILADMIN_UNLIMITED -1
+#define MAX_LANG_STR 350
 
-/*#define DEFAULT_MAX_POP_USERS      QMAILADMIN_UNLIMITED
-#define DEFAULT_MAX_ALIASES        QMAILADMIN_UNLIMITED
-#define DEFAULT_MAX_FORWARDS       QMAILADMIN_UNLIMITED
-#define DEFAULT_MAX_AUTORESPONDERS QMAILADMIN_UNLIMITED
-#define DEFAULT_MAX_MAILINGLISTS   QMAILADMIN_UNLIMITED
-*/
+#define QMAILADMIN_UNLIMITED -1
 
 #define NO_ADMIN		0
 
 #define DOMAIN_ADMIN	2
 #define USER_ADMIN		3
 
-
-#define NUM_EZMLM_NO_IDX_CHOICES 2 
-#define NUM_EZMLM_IDX_CHOICES 19
 #define NUM_SQL_OPTIONS	  6
 
-char *get_html_text( char *index );
-int open_lang( char *lang);
+#define ACTION_MODIFY 1
+#define ACTION_DELETE 2
+
+void del_id_files( char *);
+void init_globals();
+void quickAction (char *username, int action);
+
+/* copied from maildirquota.c in vpopmail
+ * it really needs to get into vpopmail.h somehow
+ */
+int readuserquota(const char* dir, long *sizep, int *cntp);
